@@ -38,7 +38,7 @@ let call = match post with
   let body = call#request_body in
   call#set_request_uri (Printf.sprintf "http://%s:%d%s" host port req) ;
   let headers = ("User-agent",
-      Printf.sprintf "ocaml-lastfm/%s" Constants.version) 
+      Printf.sprintf "ocaml-lastfm/%s" Lastfm_constants.version) 
       :: headers
   in
   http_headers#set_fields headers ;
@@ -127,7 +127,7 @@ module Audioscrobbler=
         | Not_found -> UnknownError "unrecognized response code"
 
     (* Protocol constants *)
-    let version = "1.2"
+    let version = "1.2.1"
     let base_port = 80
     let base_host = "post.audioscrobbler.com"
     let handshake_req = Printf.sprintf "/?hs=true&p=%s&c=%s&v=%s&u=%s&t=%s&a=%s" version
@@ -279,7 +279,7 @@ module Audioscrobbler=
           in
           let s =  match s with 
                      | Some User -> "P"
-                     | Some Broadcast -> "P"
+                     | Some Broadcast -> "R"
                      | Some Recommendation -> "E"
                      | Some Lastfm -> "L"
                      | Some Unknown -> "U"
